from ._gitfame import __author__
from ._gitfame import __date__
from ._gitfame import __licence__
from ._gitfame import __copyright__
from ._gitfame import __version__
from ._gitfame import __license__

__all__ = ['main', '__author__', '__date__', '__licence__', '__copyright__',
           '__version__', '__license__']
